<?php

namespace Drupal\entity_template_select;

use Drupal\Core\Config\ConfigFactory;
use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides dynamic permissions of the entity template select module.
 */
class EntityTemplateSelectPermissions implements ContainerInjectionInterface {

  use StringTranslationTrait;

  /**
   * The config factory.
   *
   * @var \Drupal\Core\Config\ConfigFactory
   */
  protected $configFactory;

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Constructs a new EntityTemplateSelectPermissions instance.
   *
   * @param \Drupal\Core\Config\ConfigFactory $config_factory
   *   The config factory.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   */
  public function __construct(ConfigFactory $config_factory, EntityTypeManagerInterface $entity_type_manager) {
    $this->configFactory = $config_factory;
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('entity_type.manager')
    );
  }

  /**
   * Returns an array of filter permissions.
   *
   * @return array
   *   An array of permission.
   */
  public function permissions() {
    $permissions = [];
    $cfEntities = $this->configFactory->get('entity_template_select.entity_template_setting')->get('entities');
    $entities = $this->entityTypeManager->getDefinitions();
    if (!empty($cfEntities)) {
      foreach ($cfEntities as $entity_type) {
        if (empty($entity_type)) {
          continue;
        }

        $permissions["allow users to pick $entity_type templates"] = [
          'title' => $this->t('%entity_type: Enable Entity Template Select', [
            '%entity_type' => $entities[$entity_type]->get('label'),
          ]
          ),
        ];
      }
    }
    return $permissions;
  }

}
