<?php

namespace Drupal\entity_template_select\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Entity\EntityTypeRepositoryInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Class EntityTemplateSelectSettingForm.
 */
class EntityTemplateSelectSettingForm extends ConfigFormBase {

  /**
   * Config name.
   */
  const SETTINGS = 'entity_template_select.entity_template_setting';


  /**
   * The Entity Repository.
   *
   * @var \Drupal\Core\Entity\EntityTypeRepositoryInterface
   */
  protected $entityRepository;

  /**
   * Constructs a SettingsForm object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The factory for configuration objects.
   * @param \Drupal\Core\Entity\EntityTypeRepositoryInterface $entity_type_repository
   *   The entity type repository.
   */
  public function __construct(ConfigFactoryInterface $config_factory, EntityTypeRepositoryInterface $entity_type_repository) {
    parent::__construct($config_factory);
    $this->entityRepository = $entity_type_repository;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('entity_type.repository')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'entity_template_select_setting_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      static::SETTINGS,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config(static::SETTINGS);
    $entities = $this->entityRepository->getEntityTypeLabels(TRUE);

    $form['entities'] = [
      '#type' => 'checkboxes',
      '#title' => $this->t('Entities'),
      '#description' => $this->t('Choose entity use select template function.'),
      '#options' => $entities['Content'],
      '#default_value' => empty($config->get('entities')) ? [] : $config->get('entities'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Retrieve the configuration.
    $this->configFactory->getEditable(static::SETTINGS)
      ->set('entities', $form_state->getValue('entities'))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
